@@ -1508,7 +1508,7 @@ class Database:
         freq_valid = True if freq in freq_list else False
 
         try:
-            index_name = (index == 'HSI') or (index == 'HHI')
+            index_name = (index == 'HSI') or (index == 'HHI') or (index == 'HTI')
         except:
             index_name = False
         try:
